---
title: Routing
description: Learn the fundamentals of routing for front-end applications with the Pages Router.
---

The Pages Router has a file-system based router built on concepts of pages. When a file is added to the `pages` directory it's automatically available as a route. Learn more about routing in the Pages Router:
